<?php
/* This file is part of Jeedom.
*
* Jeedom is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* Jeedom is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with Jeedom. If not, see <http://www.gnu.org/licenses/>.

Basic examples :
Use : parseIPX800xml.php ipx=IPX_IP tag=TAG_WANTED
Or  : parseIPX800xml.php ipx=IPX_IP tag=TAG_WANTED user=MY_USER pass=MY_PASSWORD

Examples for Analog Inputs :
Use : parseIPX800xml.php ipx=IPX_IP tag=TAG_WANTED factor=MY_FACTOR
Or  : parseIPX800xml.php ipx=IPX_IP tag=TAG_WANTED factor=MY_FACTOR round=MY_ROUND
Or  : parseIPX800xml.php ipx=IPX_IP tag=TAG_WANTED sensor=MY_SENSOR
Or  : parseIPX800xml.php ipx=IPX_IP tag=TAG_WANTED user=MY_USER pass=MY_PASSWORD sensor=MY_SENSOR
Or  : ...

For "led" tag you can personalise the result type (ON/OFF or 0/1 or ...) with "on=MY_ON" and "off=MY_OFF" parameters.
For "btn" tag you can personalise the result type (ON/OFF or DOWN/UP or ...) with "up=MY_UP" and "down=MY_DOWN" parameters.
By default, the script just return ON/OFF values for both tags.
Example : parseIPX800xml.php ipx=IPX_IP tag=ledX on=MY_ON off=MY_OFF


Parameters : IPX_IP is IP adresse of the IPX800.
             TAG_WANTED is the name of the value wanted (See status.xml).
             MY_USER is the user name if authentication in turn on in the IPX800.
             MY_PASSWORD is the password if authentication in turn on in the IPX800.
             MY_FACTOR is the conversion factor to apply to analog inputs.
             MY_ROUND is the number of digits after the decimal point.
             MY_SENSOR is the sensor type among case 'Volt', 'TC4012', 'LS100', 'TC5050', 'RH100' or 'TC100'.
             MY_ON is the result wanted when asking for a "led" tag that is On.
             MY_OFF is the result wanted when asking for a "led" tag that is Off.
             MY_UP is the result wanted when asking for a "btn" tag that is Up.
             MY_DOWN is the result wanted when asking for a "btn" tag that is Down.
        
*/

if (isset($argv)) {
    foreach ($argv as $arg) {
        $argList = explode('=', $arg);
        if (isset($argList[0]) && isset($argList[1])) {
                $_GET[$argList[0]] = $argList[1];
        }
    }
}

if (isset($_GET['ipx'])) {
        if (isset($_GET['user'])) {
                if (isset($_GET['pass'])) {
                        $url = 'http://' . $_GET['user'] . ':' . $_GET['pass'] . '@' . $_GET['ipx'] . '/status.xml';
                } else {
                        $err = 'ERROR : [pass] argument is mandatory if [user] is provided (ex:pass=rosebud ) !';
                }
        } else {
                if (isset($_GET['pass'])){
                        $err = 'ERROR : [user] argument is mandatory if [pass] is provided (ex:user=kane ) !';
                } else {
                        $url = 'http://' . $_GET['ipx'] . '/status.xml';
                }
        }
} else {
  $err = 'ERROR : [ipx] argument is mandatory (ex: ipx=192.168.1.45) !';
}

if (!isset($err)) {
        if (isset($_GET['tag'])) {
                $tag = $_GET['tag'];

                $xml = new SimpleXMLElement($url, Null, True);
                $nodes = $xml->xpath('//' . $tag);

                if (!isset($nodes[0])) {
                        echo 'ERROR : Tag "' . $tag . '"not found in xml file';
                } else {
                        switch (substr($tag, 0, 3)) {
                                case 'led':
                                        if ($nodes[0] == 1) {
                                                if (isset($_GET['on'])) {
                                                        echo $_GET['on'];
                                                } else {
                                                        echo 'ON';
                                                }
                                        } else {
                                                if (isset($_GET['off'])) {
                                                        echo $_GET['off'];
                                                } else {
                                                        echo 'OFF';
                                                }
                                        }
                                        break;
                                case 'btn':
                                        if ($nodes[0] == 'up') {
                                                if (isset($_GET['up'])) {
                                                        echo $_GET['up'];
                                                } else {
                                                        echo 'OFF';
                                                }
                                        } else {
                                                 if (isset($_GET['down'])) {
                                                        echo $_GET['down'];
                                                } else {
                                                        echo 'ON';
                                                }
                                        }
                                        break;
                                case 'ana':
                                case 'an1':
                                case 'an2':
                                        if (isset($_GET['sensor'])) {
                                                $sensor = $_GET['sensor'];

                                                /*      Source http://gce-electronics.com/forum/viewtopic.php?f=31&t=1645
                                                        Voici le calcul pour trouver la valeur d'une sonde en fonction de la valeur analogique de l'ipx800.
                                                        Volt   = valeur analogique * 0.00323
                                                        TC4012 = ( valeur analogique * 0.323) - 50
                                                        LS100  = valeur analogique * 0.09775
                                                        TC5050 = (( valeur analogique * 0.00323) - 1.63) / 0.0326
                                                        RH100  = ((( valeur analogique * 0.00323) / 3.3) - 0.1515)) / 0.00636
                                                        TC100  = ( ( valeur analogique * 0.00323) - 0.25) / 0.028
                                                */

                                                switch ($sensor) {
                                                        case 'Volt' :
                                                                $ret = $nodes[0] * 0.00323;
                                                                break;
                                                        case 'TC4012' :
                                                                $ret = ($nodes[0] * 0.323) - 50;
                                                                break;
                                                        case 'LS100' :
                                                                $ret = $nodes[0] * 0.09775;
                                                                break;
                                                        case 'TC5050' :
                                                                $ret = (($nodes[0] * 0.00323) - 1.63) / 0.0326;
                                                                break;
                                                        case 'RH100' :
                                                                $ret = ((($nodes[0] * 0.00323) / 3.3) - 0.1515) / 0.00636;
                                                                break;
                                                        case 'TC100':
                                                                $ret = (($nodes[0] * 0.00323) - 0.25) / 0.028;
                                                                break;
                                                        default:
                                                                echo 'ERROR : Unknown "' . $sensor . '"sensor type';
                                                }
                                        } else {
                                                if (isset($_GET['factor'])) {
                                                        $ret = $nodes[0] * $_GET['factor'];
                                                } else {
                                                        $ret = $nodes[0];
                                                }
                                        }

                                        if (isset($_GET['round'])) {
                                                echo round($ret, $_GET['round']);
                                        } else {
                                                echo $ret;
                                        }
                                        break;
                                default:
                                        echo $nodes[0];
                        }
                }
        } else {
                echo 'ERROR : [tag] argument is mandatory (ex: tag=version) !';
        }
} else {
        echo $err;
}
exit;
?>